"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BudBabelExtension = void 0;
const bud_build_1 = require("@roots/bud-build");
const fs_extra_1 = require("fs-extra");
const _1 = require(".");
/**
 * Adds Babel transpiler support to Framework projects
 *
 * @public @config
 */
exports.BudBabelExtension = {
    /**
     * Extension name
     *
     * @public
     */
    name: '@roots/bud-babel',
    /**
     * Extension register event
     *
     * @public
     */
    register(app) {
        app.extensions.bindClass({
            babel: [_1.Config, app],
        });
        app.build.loaders.babel = new bud_build_1.Loader(require.resolve('babel-loader'));
        app.build.items.babel = new bud_build_1.Item({
            loader: ({ build }) => build.loaders.babel,
            options: app => {
                var _a, _b;
                const options = {
                    cacheDirectory: app.path('storage', 'cache', 'babel'),
                    env: {
                        development: {
                            compact: false,
                        },
                    },
                    root: app.path('src'),
                };
                if ((_a = app.babel) === null || _a === void 0 ? void 0 : _a.presets) {
                    options.presets = Object.values(app.babel.presets);
                }
                if ((_b = app.babel) === null || _b === void 0 ? void 0 : _b.plugins) {
                    options.plugins = Object.values(app.babel.plugins);
                }
                return options;
            },
        });
        app.build.rules.js.setUse(({ build }) => [build.items.babel]);
    },
    /**
     * Extension boot event
     *
     * @public
     */
    boot(app) {
        !(0, fs_extra_1.existsSync)(app.path('project', 'babel.config.js')) &&
            app.babel
                .setPresets(_1.DEFAULT_PRESETS)
                .setPlugins(_1.DEFAULT_PLUGINS);
    },
};
//# sourceMappingURL=BudBabelExtension.js.map