"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Config = void 0;
const tslib_1 = require("tslib");
const bud_support_1 = require("@roots/bud-support");
const { isString } = bud_support_1.lodash;
class Config {
    constructor(app) {
        /**
         * @public
         */
        this.name = '@roots/bud-babel';
        this.plugins = {};
        this.presets = {};
        this._app = () => app;
    }
    get app() {
        return this._app();
    }
    normalizeEntry(c) {
        return isString(c)
            ? [c, {}]
            : c;
    }
    setPlugin(plugin) {
        plugin = this.normalizeEntry(plugin);
        this.plugins = Object.assign(Object.assign({}, this.plugins), { [plugin[0]]: plugin });
        return this;
    }
    setPlugins(plugins) {
        plugins.map(this.setPlugin);
        return this;
    }
    setPreset(preset) {
        preset = this.normalizeEntry(preset);
        this.presets = Object.assign(Object.assign({}, this.presets), { [preset[0]]: preset });
        return this;
    }
    setPresets(presets) {
        presets.map(this.setPreset);
        return this;
    }
    unsetPreset(preset) {
        !this.presets[preset]
            ? this.app.error(`${preset} not found`)
            : delete this.presets[preset];
        return this;
    }
    unsetPlugin(plugin) {
        !this.plugins[plugin]
            ? this.app.error(`${plugin} not found`)
            : delete this.plugins[plugin];
        return this;
    }
    setPluginOptions(plugin, options) {
        this.plugins[plugin] = [this.plugins[plugin][0], options];
        return this;
    }
    setPresetOptions(preset, options) {
        this.presets[preset] = [this.presets[preset][0], options];
        return this;
    }
}
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "normalizeEntry", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "setPlugin", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "setPlugins", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "setPreset", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "setPresets", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "unsetPreset", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "unsetPlugin", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "setPluginOptions", null);
(0, tslib_1.__decorate)([
    bud_support_1.bind
], Config.prototype, "setPresetOptions", null);
exports.Config = Config;
//# sourceMappingURL=Config.js.map